@@ -1,17 +1,16 @@
 package Bitcoin::Crypto::Key::Private;
-$Bitcoin::Crypto::Key::Private::VERSION = '2.005';
+$Bitcoin::Crypto::Key::Private::VERSION = '2.006';
 use v5.10;
 use strict;
 use warnings;
 use Moo;
 use Crypt::PK::ECC;
 use Bitcoin::BIP39 qw(bip39_mnemonic_to_entropy entropy_to_bip39_mnemonic);
-use Type::Params -sigs;
+use Types::Common -sigs, -types;
 use List::Util qw(none);
 
 use Bitcoin::Crypto::Key::Public;
 use Bitcoin::Crypto::Base58 qw(encode_base58check decode_base58check);
-use Bitcoin::Crypto::Types qw(Object Str Maybe);
 use Bitcoin::Crypto::Constants;
 use Bitcoin::Crypto::Network;
 use Bitcoin::Crypto::Util qw(validate_wif);
