@@ -1,15 +1,14 @@
 package Bitcoin::Crypto::Network;
-$Bitcoin::Crypto::Network::VERSION = '2.005';
+$Bitcoin::Crypto::Network::VERSION = '2.006';
 use v5.10;
 use strict;
 use warnings;
 
 use Moo;
 use Mooish::AttributeBuilder -standard;
-use Type::Params -sigs;
+use Types::Common -sigs, -types;
 
 use Bitcoin::Crypto::Exception;
-use Bitcoin::Crypto::Types qw(Object HashRef CodeRef Str StrLength Int Maybe);
 
 use namespace::clean;
 
