@@ -1,12 +1,11 @@
 package Bitcoin::Crypto::Role::Compressed;
-$Bitcoin::Crypto::Role::Compressed::VERSION = '2.005';
+$Bitcoin::Crypto::Role::Compressed::VERSION = '2.006';
 use v5.10;
 use strict;
 use warnings;
 use Mooish::AttributeBuilder -standard;
-use Type::Params -sigs;
+use Types::Common -sigs, -types;
 
-use Bitcoin::Crypto::Types qw(Object Bool);
 use Moo::Role;
 
 has param 'compressed' => (
