@@ -1,13 +1,13 @@
 package Bitcoin::Crypto::Script::Common;
-$Bitcoin::Crypto::Script::Common::VERSION = '2.005';
+$Bitcoin::Crypto::Script::Common::VERSION = '2.006';
 use v5.10;
 use strict;
 use warnings;
 
-use Type::Params -sigs;
+use Types::Common -sigs, -types;
 
 use Bitcoin::Crypto qw(btc_script);
-use Bitcoin::Crypto::Types qw(Str ByteStr InstanceOf);
+use Bitcoin::Crypto::Types -types;
 use Bitcoin::Crypto::Exception;
 
 sub _make_PKH
