@@ -1,17 +1,12 @@
 package Bitcoin::Crypto::Types;
-$Bitcoin::Crypto::Types::VERSION = '2.005';
+$Bitcoin::Crypto::Types::VERSION = '2.006';
 use v5.10;
 use strict;
 use warnings;
 
-use Type::Library -extends => [
-	qw(
-		Types::Standard
-		Types::Common::Numeric
-		Types::Common::String
-	)
-];
+use Type::Library -base;
 use Type::Coercion;
+use Types::Common -types;
 
 # make sure Math::BigInt is properly loaded - this module loads it
 use Bitcoin::Crypto::Helpers;
@@ -115,7 +110,7 @@ __PACKAGE__->add_type(
 	parent => PositiveOrZeroInt,
 
 	constraint_generator => sub {
-		my $bits = assert_PositiveInt(shift);
+		my $bits = PositiveInt->assert_valid(shift);
 
 		# for same bits as system, no need for special constraint
 		return sub { 1 }
@@ -162,10 +157,108 @@ $satoshi_amount->coercion->add_type_coercions(
 	Int | Str, q{ Math::BigInt->new($_) },
 );
 
+my $derivation_path = __PACKAGE__->add_type(
+	name => 'DerivationPath',
+	parent => InstanceOf->of('Bitcoin::Crypto::DerivationPath'),
+);
+
+$derivation_path->coercion->add_type_coercions(
+	Str, q{ require Bitcoin::Crypto::DerivationPath; Bitcoin::Crypto::DerivationPath->from_string($_) },
+	ConsumerOf->of('Bitcoin::Crypto::Role::WithDerivationPath'), q{ $_->get_derivation_path },
+);
+
 __PACKAGE__->make_immutable;
 
 1;
 
-# This module is mostly used internally, but it can be used from outside for
-# bitcoin-specific types like BIP44Purpose.
+__END__
+=head1 NAME
+
+Bitcoin::Crypto::Types - Bitcoin-specific data types
+
+=head1 SYNOPSIS
+
+	use Bitcoin::Crypto::Types qw(
+		BIP44Purpose
+		FormatStr
+		FormatDesc
+		ByteStr
+		ScriptType
+		ScriptDesc
+		BitcoinScript
+		PSBTMapType
+		PSBTFieldType
+		IntMaxBits
+		SatoshiAmount
+	);
+
+=head1 DESCRIPTION
+
+This module is a L<Type::Tiny> library for types which are either specific for
+Bitcoin or are used by Bitcoin::Crypto to implement its routines.
+
+=head1 AVAILABLE TYPES
+
+=head2 BIP44Purpose
+
+An integer with one of the available purpose numbers for BIP44, like C<44>.
+
+=head2 FormatStr
+
+A string with one of the available format names, like C<hex>.
+
+=head2 FormatDesc
+
+An array reference with exactly two elements, where the first one is
+L</FormatStr> and the second one is a string with the data encoded in that
+format.
+
+=head2 ByteStr
+
+A string where each character is 8 bit. Can be coerced from L</FormatDesc>.
+
+=head2 ScriptType
+
+A string with one of the available script type names, like C<P2WPKH>.
+
+=head2 ScriptDesc
+
+An array reference with exactly two elements, where the first one is
+L</ScriptType> or a string C<address>, and the second one is defined data
+specific for that script type.
+
+=head2 BitcoinScript
+
+An instance of L<Bitcoin::Crypto::Script>. Can be coerced from L</ScriptDesc>
+or L</ByteStr> (or any of its coercion types).
+
+=head2 PSBTMapType
+
+A string with one of the available PSBT map type names, like C<global>.
+
+=head2 PSBTFieldType
+
+An instance of L<Bitcoin::Crypto::PSBT::FieldType>. Can be coerced from a
+string name of the PSBT field, or from an array reference of two values, where
+the first one is L</PSBTMapType> and the second one is a positive integer with
+field code.
+
+=head2 IntMaxBits
+
+A non-negative integer which must be small enough to be representable with the
+specified number of bits (parametrizable).
+
+=head2 SatoshiAmount
+
+A non-negative integer, represented as L<Math::BigInt> object. Can be coerced
+from an integer or from a string.
+
+=head2 DerivationPath
+
+An instance of L<Bitcoin::Crypto::DerivationPath>. Can be coerced from a string
+or a class consuming C<Bitcoin::Crypto::Role::WithDerivationPath>.
+
+=head1 SEE ALSO
+
+L<Type::Library>
 
