@@ -1,5 +1,5 @@
 package Bitcoin::Crypto::Util;
-$Bitcoin::Crypto::Util::VERSION = '2.005';
+$Bitcoin::Crypto::Util::VERSION = '2.006';
 use v5.10;
 use strict;
 use warnings;
@@ -12,12 +12,11 @@ use Crypt::Digest::SHA256 qw(sha256);
 use Bitcoin::BIP39 qw(gen_bip39_mnemonic entropy_to_bip39_mnemonic);
 use Try::Tiny;
 use Scalar::Util qw(blessed);
-use Type::Params -sigs;
+use Types::Common -sigs, -types;
 
 use Bitcoin::Crypto::Helpers qw(parse_formatdesc);
 use Bitcoin::Crypto::Constants;
-use Bitcoin::Crypto::Types qw(Str ByteStr FormatStr ConsumerOf Maybe PositiveInt Tuple ScalarRef PositiveOrZeroInt);
-use Bitcoin::Crypto::DerivationPath;
+use Bitcoin::Crypto::Types -types;
 use Bitcoin::Crypto::Exception;
 
 our @EXPORT_OK = qw(
@@ -272,16 +271,16 @@ sub mnemonic_from_entropy
 }
 
 signature_for get_path_info => (
-	positional => [Str | ConsumerOf ['Bitcoin::Crypto::Role::WithDerivationPath']],
+	positional => [Defined],
 );
 
 sub get_path_info
 {
 	my ($path) = @_;
-	return $path->get_derivation_path if blessed $path;
 
+	# NOTE: ->coerce may still throw because of exceptions in from_string of DerivationPath
 	return scalar try {
-		Bitcoin::Crypto::DerivationPath->from_string($path);
+		DerivationPath->assert_coerce($path);
 	};
 }
 
@@ -565,6 +564,10 @@ L<Bitcoin::Crypto::DerivationPath>:
 		],
 	}
 
+You may also use L<Bitcoin::Crypto::Types/DerivationPath> type and its
+coercions to achieve the same effect (but with an exception instead of undef on
+failure).
+
 =head2 to_format
 
 	$encoded = to_format [$format => $bytes];
